/**************************************************************************
 * 
 * Copyright (C) 2011 Nena Innovation AB. All rights reserved.
 *
 **************************************************************************/

// BlendMesh shader, mixes two vertex sets.

uniform mat4 u_viewProj;
uniform mat4 u_model;
uniform vec3 u_lightPos;
uniform float u_weight;
uniform vec2 u_lightMod;

attribute vec3 a_vertex_0;
attribute vec3 a_normal_0;
attribute vec3 a_vertex_1;
attribute vec3 a_normal_1;
attribute vec2 a_texcoord;

varying float v_light;
varying vec2 v_texCoord;

void main()
{
  vec4 b_pos = vec4((1.0-u_weight)*a_vertex_0+u_weight*a_vertex_1, 1.0);
  vec4 b_nor = vec4((1.0-u_weight)*a_normal_0+u_weight*a_normal_1, 0.0);
  
  vec4 w_pos = u_model*b_pos;
  vec4 w_nor = u_model*b_nor; 

  vec3 lightdir = normalize(u_lightPos - w_pos.xyz);
  float diff = max(0.0, dot(lightdir, w_nor.xyz));

  v_texCoord = a_texcoord;
  v_light = u_lightMod[0]+u_lightMod[1]*diff;
  gl_Position = u_viewProj * b_pos;
}
