/**************************************************************************
 * 
 * Copyright (C) 2011 Nena Innovation AB. All rights reserved.
 * 
 **************************************************************************/

// Skinned Mesh shader, each vertex have two matrix weigthts. Maximum 
// armature size is 16.

uniform mat4 u_viewProj;
uniform mat4 u_model;
uniform mat4 u_bones[16];
uniform vec3 u_lightPos;
uniform vec3 u_lightCol;
uniform vec2 u_lightMod;

attribute vec3 a_vertex;
attribute vec4 a_bones; // (bone_id_0, bone_id_0_value, bone_id_1, bone_id_1_value)
attribute vec3 a_normal;
attribute vec2 a_texcoord;

varying vec3 v_light;
varying vec2 v_texCoord;

void main()
{
  vec4 b0p = u_bones[int(a_bones.x)]*vec4(a_vertex, 1.0);
  vec4 b1p = u_bones[int(a_bones.z)]*vec4(a_vertex, 1.0);
  vec4 b_pos =  a_bones.y*b0p + a_bones.w*b1p;

  vec4 b0n = u_bones[int(a_bones.x)]*vec4(a_normal, 0.0);
  vec4 b1n = u_bones[int(a_bones.z)]*vec4(a_normal, 0.0);
  vec4 b_nor = a_bones.y*b0n + a_bones.w*b1n;  
  
  vec4 wb_pos = u_model*b_pos;
  vec4 wb_nor = u_model*vec4(b_nor.xyz, 0.0); 

  vec3 lightdir = normalize(u_lightPos - wb_pos.xyz);
  float diff = max(0.0, dot(lightdir, wb_nor.xyz));

  v_texCoord = a_texcoord;
  v_light = (u_lightMod[0]+u_lightMod[1]*diff)*u_lightCol;;
  gl_Position = u_viewProj * b_pos;
}
