/**************************************************************************
 * 
 * Copyright (C) 2011 Nena Innovation AB. All rights reserved.
 * 
 **************************************************************************/

// Water shader for lake.

#ifdef GL_ES
precision mediump float;
#endif

uniform sampler2D u_reflTex;
uniform sampler2D u_normTex;
uniform sampler2D u_maskTex;
uniform vec2 u_screenRes;
uniform vec2 u_lightMod;

varying vec2 v_texCoordWave;
varying vec2 v_texCoordMask;
varying vec3 v_eyeVec;

const float c_waveFactor = 0.15;

void main()
{
  // Shore mask
  float mask = 1.0-texture2D(u_maskTex, v_texCoordMask).a;
  
  // Normal
  vec3 bump = ((2.0*texture2D(u_normTex, v_texCoordWave).xyz) - vec3(1.0));
  vec3 norm = mask*bump+(1.0-mask)*vec3(0.0, 0.0, 1.0);
  
  // Fresnel
  float fres = 1.0 - dot(norm,v_eyeVec);
    
  // Reflection
  vec2 nc = gl_FragCoord.xy*u_screenRes;
  nc += mask*norm.xy*c_waveFactor;
  vec4 refl = texture2D(u_reflTex, nc.xy);
  
  // Depth
  float depth_factor = 0.5+0.5*(1.0-gl_FragCoord.z);
  
  gl_FragColor = vec4(depth_factor*refl.xyz, fres);
}


